This is basically a data structure that takes "Xigtified" Toolbox data
and organizes it so that MOM can use it. There is an additional module
that performs some consistency checks and will alert you if it suspects
misalignments in the original Toolbox data.